#ifndef SMSWINDOW_H
#define SMSWINDOW_H

#include <QDialog>
#include "settings.h"
#include "vodafonewidget.h"

namespace Ui {
    class SmsWindow;
}

class SmsWindow : public QDialog
{
    Q_OBJECT

public:
    explicit SmsWindow(QWidget *parent = 0, VodafoneWidget* vodafone=0, Settings* settings=0);
    ~SmsWindow();

private:
    Ui::SmsWindow *ui;
    Settings* m_Settings;
    VodafoneWidget* m_Vodafone;

    void StopWait();

private slots:
    void ContactsSlot();
    void SendSlot();
    void CancelSlot();
    void MessageChangedSlot();
};

#endif // SMSWINDOW_H
